@@ -6,11 +6,21 @@
 import logging
 import os
 
+try:
+    # noinspection PyCompatibility
+    from importlib.metadata import version
+except ModuleNotFoundError:
+    # noinspection PyUnresolvedReferences
+    # <3.8 backport
+    from importlib_metadata import version
+
+try:
+    __version__ = version(__name__)
+except Exception:
+    pass
+
 from appdirs import AppDirs
 
-__author__ = """Hiroyuki Takagi"""
-__email__ = 'miyako.dev@gmail.com'
-__version__ = '0.0.25'
 __chromium_revision__ = '588429'
 __base_puppeteer_version__ = 'v1.6.0'
 __pyppeteer_home__ = os.environ.get(
@@ -18,13 +28,9 @@ __pyppeteer_home__ = os.environ.get(
 DEBUG = False
 
 # Setup root logger
-_logger = logging.getLogger('pyppeteer')
-_log_handler = logging.StreamHandler()
 _fmt = '[{levelname[0]}:{name}] {msg}'
-_formatter = logging.Formatter(fmt=_fmt, style='{')
-_log_handler.setFormatter(_formatter)
-_log_handler.setLevel(logging.DEBUG)
-_logger.addHandler(_log_handler)
+logging.basicConfig(level=logging.DEBUG, format=_fmt, style='{')
+_logger = logging.getLogger(__name__)
 _logger.propagate = False
 
 from pyppeteer.launcher import connect, launch, executablePath  # noqa: E402
